@@ -12,11 +12,29 @@ gdrate <- function(input, pval, plots) {
     jdta <- data.frame(cbind(time, f))
     colnames(jdta) <- c("time", "f")
     v <- subset(foo, foo$IDmodel == i)
-    outgd <- nlsLM(eval(parse(text = paste(v$model))), data = jdta, start = eval(parse(text = paste(v$start))),
-                   control = nls.lm.control(maxiter = 1000, maxfev = 1000, factor = 0.01,
-                                            ftol = .Machine$double.eps, ptol = .Machine$double.eps), lower = eval(parse(text = paste(v$lb))),
-                   upper = eval(parse(text = paste(v$ub))))
-    return(outgd)
+
+    try({
+      outgd <- nlsLM(eval(parse(text = paste(v$model))), data = jdta, start = eval(parse(text = paste(v$start))),
+                     control = nls.lm.control(maxiter = 1000, maxfev = 1000, factor = 0.01,
+                                              ftol = sqrt(.Machine$double.eps),
+                                              ptol = sqrt(.Machine$double.eps)),
+                     lower = eval(parse(text = paste(v$lb))),
+                     upper = eval(parse(text = paste(v$ub))))
+    }, silent = TRUE)
+
+    if(!exists("outgd") && i == 4 ){
+      try({
+        outgd2 <- stats::nls(eval(parse(text = paste(v$model))), data = jdta,
+                      start = eval(parse(text = paste(v$start))),
+                      algorithm = 'port',
+                      control = stats::nls.control(maxiter = 1000, warnOnly = FALSE, minFactor = .000001),
+                      lower = eval(parse(text = paste(v$lb))),
+                      upper = eval(parse(text = paste(v$ub))))
+      }, silent = TRUE)
+      return(outgd2)
+    } else {
+      return(outgd)
+    }
   }
 
   # Function to prepare user input data for modeling
@@ -26,9 +44,7 @@ gdrate <- function(input, pval, plots) {
       stop("input argument missing")
     } else {
       try({
-        #input <- input1[complete.cases(input1), ]
         input <- input1[stats::complete.cases(input1), ]
-
       }, silent = TRUE)
       if (dim(input)[1] < 1) {
         stop("input contains no non-missing data")
@@ -172,7 +188,10 @@ gdrate <- function(input, pval, plots) {
 
     # model given input and i
     outgd <- gdX(input1, i)
-    newx <- seq(0, tseq, by = 1)
+    newx <- seq(1, tseq, by = 1)
+    dnew <- data.frame(time = newx)
+    #prd <- stats::predict(outgd, newdata = dnew)
+    #length(seq(1, tseq, by = 1))
     prd <- stats::predict(outgd, newdata = data.frame(time = newx))
 
     # merge pred with input for calc rmse
@@ -189,7 +208,7 @@ gdrate <- function(input, pval, plots) {
     #par(mar = c(6.5, 4.5, 1, 1.5))
     graphics::par(mar = c(6.5, 4.5, 1, 1.5))
     graphics::plot(f ~ time, data = jdta, frame = FALSE, col = "red", cex = 1.3, cex.axis = 1.4,
-         cex.lab = 1.6, pch = 19, xlab = "Days", ylab = "Tumor Q/Q0", main = tit)
+                   cex.lab = 1.6, pch = 19, xlab = "Days", ylab = "Tumor Q/Q0", main = tit)
     #lines(newx, prd, col = cc, lty = 1, lwd = 3)
     graphics::lines(newx, prd, col = cc, lty = 1, lwd = 3)
 
@@ -200,7 +219,7 @@ gdrate <- function(input, pval, plots) {
 
     # observed values
     graphics::points(f ~ time, data = jdta, pch = 21, col = c("black"), bg = "red", lwd = 1.2,
-           cex = 1.5)
+                     cex = 1.5)
     # return(rmse)
   }
 
@@ -267,7 +286,6 @@ gdrate <- function(input, pval, plots) {
             zout <- cbind(fit, iMod, name00, stopcode, stopMessage, isconv)
 
             if (isconv == "TRUE") {
-              #LL <- logLik(outgd)
               LL <- stats::logLik(outgd)
               AIC <- as.numeric(paste(-2 * LL + 2 * np))
               AICc <- as.numeric(paste(AIC + 2 * np * (np + 1)/(lm - np -
@@ -458,9 +476,7 @@ gdrate <- function(input, pval, plots) {
 
     # Function to generate outlist1 for gdrate fx return
     genoutlist <- function(xx) {
-      #y <- data.frame(aggregate(xx$name ~ xx$calcfinal, data = xx, length))
       y <- data.frame(stats::aggregate(xx$name ~ xx$calcfinal, data = xx, length))
-
       colnames(y) <- c("Type", "N")
       y$Percentage <- round((y$N/sum(y$N)), digits = 2) * 100
       y$Group <- ifelse((y$Type %in% paste(foo$fit)), "included", "excluded")
@@ -545,9 +561,7 @@ gdrate <- function(input, pval, plots) {
           # excluded cases not analyzed
           excl <- ip$excluded
           colnames(excl)[4] <- "N"
-          #exclm <- excl[complete.cases(excl), c("name", "calcfinal", "N")]
           exclm <- excl[stats::complete.cases(excl), c("name", "calcfinal", "N")]
-
           excl1 <- dim(exclm)[1]
           if (excl1 > 0) {
             excl2 <- exclm
@@ -581,7 +595,6 @@ gdrate <- function(input, pval, plots) {
 
           # descriptive stats by variable
           retAll <- function(vr, vc) {
-            #vals <- na.omit(vr)
             vals <- stats::na.omit(vr)
             lv <- length(vals)
             if (lv > 0) {
@@ -663,4 +676,3 @@ gdrate <- function(input, pval, plots) {
   result <- generateresults()
   return(result)
 }
-
